Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(402)

Unified Diff: src/compiler/frame-states.h

Issue 1514413002: [Interpreter] Generate valid FrameStates in the Bytecode Graph Builder. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@int_materialize_sf
Patch Set: Add checks that environment doesn't change after state nodes are attached Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/code-generator.cc ('k') | src/compiler/frame-states.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/frame-states.h
diff --git a/src/compiler/frame-states.h b/src/compiler/frame-states.h
index 8ab4d138d7d3fd76eedc6efbeb023254c46beb79..ddb55c35d245ca6286f0ef11b9ffabb384a471ac 100644
--- a/src/compiler/frame-states.h
+++ b/src/compiler/frame-states.h
@@ -76,9 +76,10 @@ class OutputFrameStateCombine {
// The type of stack frame that a FrameState node represents.
enum class FrameStateType {
- kJavaScriptFunction, // Represents an unoptimized JavaScriptFrame.
- kArgumentsAdaptor, // Represents an ArgumentsAdaptorFrame.
- kConstructStub // Represents a ConstructStubFrame.
+ kJavaScriptFunction, // Represents an unoptimized JavaScriptFrame.
+ kInterpretedFunction, // Represents an InterpretedFrame.
+ kArgumentsAdaptor, // Represents an ArgumentsAdaptorFrame.
+ kConstructStub // Represents a ConstructStubFrame.
};
@@ -108,6 +109,11 @@ class FrameStateFunctionInfo {
return context_calling_mode_;
}
+ static bool IsJSFunctionType(FrameStateType type) {
+ return type == FrameStateType::kJavaScriptFunction ||
+ type == FrameStateType::kInterpretedFunction;
+ }
+
private:
FrameStateType const type_;
int const parameter_count_;
« no previous file with comments | « src/compiler/code-generator.cc ('k') | src/compiler/frame-states.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698